@@ -117,13 +117,14 @@ barp<-function(height,width=0.4,names.arg=NULL,legend.lab=NULL,legend.pos=NULL,
   }
  }
  if(!is.null(legend.lab)) {
-  xjust<-yjust<-0.5
+  xjust<-0
+  yjust<-1
   if(is.null(legend.pos)) {
-   cat("Click at the lower left corner of the legend\n")
+   cat("Click at the upper left corner of the legend\n")
    legend.pos<-locator(1)
-   xjust<-yjust<-0
   }
-  legend(legend.pos,legend=legend.lab,fill=col,xjust=xjust,yjust=yjust)
+  legend(list(x=legend.pos[1],y=legend.pos[2]),legend=legend.lab,
+   fill=col,xjust=xjust,yjust=yjust)
  }
  box()
  invisible(barpinfo)
